summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJamie Gennis <jgennis@google.com>2013-04-09 18:37:22 -0700
committerJamie Gennis <jgennis@google.com>2013-04-10 17:50:32 -0700
commit5800fc881e9919bc8a0ce12199f2a16230c6cbbf (patch)
treef085f3fb9cb4248c3e8157e774c6a2716eb89b59
parent1e1ccfb88bf2d78d8876022fae6c5058548406e7 (diff)
downloadframeworks_base-5800fc881e9919bc8a0ce12199f2a16230c6cbbf.zip
frameworks_base-5800fc881e9919bc8a0ce12199f2a16230c6cbbf.tar.gz
frameworks_base-5800fc881e9919bc8a0ce12199f2a16230c6cbbf.tar.bz2
Trace: unhide app tracing APIs
Change-Id: I48316623fe0394d3fe77e9abca3f6dbf791d0c08
-rw-r--r--api/current.txt5
-rw-r--r--core/java/android/os/Trace.java17
2 files changed, 11 insertions, 11 deletions
diff --git a/api/current.txt b/api/current.txt
index 6ddf1a5..b3a1573 100644
--- a/api/current.txt
+++ b/api/current.txt
@@ -16989,6 +16989,11 @@ package android.os {
method public abstract void released();
}
+ public final class Trace {
+ method public static void beginSection(java.lang.String);
+ method public static void endSection();
+ }
+
public class TransactionTooLargeException extends android.os.RemoteException {
ctor public TransactionTooLargeException();
}
diff --git a/core/java/android/os/Trace.java b/core/java/android/os/Trace.java
index 310b12c..607def7 100644
--- a/core/java/android/os/Trace.java
+++ b/core/java/android/os/Trace.java
@@ -25,8 +25,6 @@ import android.util.Log;
* This tracing mechanism is independent of the method tracing mechanism
* offered by {@link Debug#startMethodTracing}. In particular, it enables
* tracing of events that occur across multiple processes.
- *
- * @hide
*/
public final class Trace {
/*
@@ -198,7 +196,7 @@ public final class Trace {
/**
* Writes a trace message to indicate that a given section of code has begun. This call must
* be followed by a corresponding call to {@link #traceEnd()} on the same thread.
*
* <p class="note"> At this time the vertical bar character '|', newline character '\n', and
* null character '\0' are used internally by the tracing mechanism. If sectionName contains
@@ -206,10 +204,8 @@ public final class Trace {
*
* @param sectionName The name of the code section to appear in the trace. This may be at
* most 127 Unicode code units long.
- *
- * @hide
*/
- public static void traceBegin(String sectionName) {
+ public static void beginSection(String sectionName) {
if (isTagEnabled(TRACE_TAG_APP)) {
if (sectionName.length() > MAX_SECTION_NAME_LEN) {
throw new IllegalArgumentException("sectionName is too long");
@@ -220,13 +216,12 @@ public final class Trace {
/**
* Writes a trace message to indicate that a given section of code has ended. This call must
* be preceeded by a corresponding call to {@link #traceBegin(String)}. Calling this method
* will mark the end of the most recently begun section of code, so care must be taken to
* ensure that traceBegin / traceEnd pairs are properly nested and called from the same thread.
*
* @hide
*/
- public static void traceEnd() {
+ public static void endSection() {
if (isTagEnabled(TRACE_TAG_APP)) {
nativeTraceEnd(TRACE_TAG_APP);
}
@@ -198,7 +196,7 @@ public final class Trace {
/**
* Writes a trace message to indicate that a given section of code has begun. This call must
- * be followed by a corresponding call to {@link #traceEnd()} on the same thread.
+ * be followed by a corresponding call to {@link #endSection()} on the same thread.
*
* <p class="note"> At this time the vertical bar character '|', newline character '\n', and
@@ -220,13 +216,12 @@ public final class Trace {
/**
* Writes a trace message to indicate that a given section of code has ended. This call must
- * be preceeded by a corresponding call to {@link #traceBegin(String)}. Calling this method
+ * be preceeded by a corresponding call to {@link #beginSection(String)}. Calling this method
* will mark the end of the most recently begun section of code, so care must be taken to
@@ -220,13 +216,12 @@ public final class Trace {
* will mark the end of the most recently begun section of code, so care must be taken to
- * ensure that traceBegin / traceEnd pairs are properly nested and called from the same thread.
- *
- * @hide
+ * ensure that beginSection / endSection pairs are properly nested and called from the same
+ * thread.
*/